@@ -4,12 +4,16 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: sizer.h,v 1.11 2004/08/04 20:22:01 mbarbon Exp $
-// Copyright:   (c) 2000-2003 Mattia Barbon
+// RCS-ID:      $Id: sizer.h,v 1.13 2005/06/26 13:58:22 mbarbon Exp $
+// Copyright:   (c) 2000-2004 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
 
+#if !WXWIN_COMPATIBILITY_2_4
+#include "cpp/wxsizer.h"
+#endif
+
 class wxPlSizer:public wxSizer
 {
     WXPLI_DECLARE_DYNAMIC_CLASS( wxPlSizer );
