@@ -3,8 +3,8 @@
 // Purpose:     constants for Wx::STC
 // Author:      Marcus Friedlaender and Mattia Barbon
 // Created:     23/05/2002
-// RCS-ID:      $Id: st_constants.cpp,v 1.16 2004/08/03 21:32:11 mbarbon Exp $
-// Copyright:   (c) 2002-2004 Marcus Friedlaender and Mattia Barbon
+// RCS-ID:      $Id: st_constants.cpp,v 1.20 2005/06/26 14:08:19 mbarbon Exp $
+// Copyright:   (c) 2002-2005 Marcus Friedlaender and Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -499,6 +499,7 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LEX_SQL );
         r( wxSTC_LEX_TCL );
 #if WXPERL_W_VERSION_GE( 2, 5, 2 )
+        r( wxSTC_LEX_YAML );
         r( wxSTC_LEX_TEX );
 #endif
         r( wxSTC_LEX_VB );
@@ -725,6 +726,11 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_SCRIPTOL_OPERATOR );
         r( wxSTC_SCRIPTOL_IDENTIFIER );
         r( wxSTC_SCRIPTOL_STRINGEOL );
+#if WXPERL_W_VERSION_GE( 2, 6, 0 )
+        r( wxSTC_SEL_STREAM );
+        r( wxSTC_SEL_RECTANGLE );
+        r( wxSTC_SEL_LINES );
+#endif
 
         r( wxEVT_STC_CHANGE );
         r( wxEVT_STC_STYLENEEDED );
